@@ -1,5 +1,7 @@
+from datetime import datetime
 import logging
-from typing import List
+from git import Reference
+from typing import List, Optional
 from enum import Enum, unique
 
 
@@ -21,36 +23,52 @@ class Level(str, Enum):
 class Issue:
 
     @classmethod
-    def info(cls, description: str):
+    def info(cls, description: str, obj: Optional[Reference]=None):
         """
-        Creates an ``Issue`` with INFO severity
+        Creates an ``Issue`` with INFO severity for related git object
         """
-        return cls(Level.INFO, description)
+        return cls(Level.INFO, description, obj)
 
     @classmethod
-    def warning(cls, description: str):
+    def warning(cls, description: str, obj: Optional[Reference]=None):
         """
-        Creates an ``Issue`` with WARNING severity
+        Creates an ``Issue`` with WARNING severity for related git object
         """
-        return cls(Level.WARNING, description)
+        return cls(Level.WARNING, description, obj)
 
     @classmethod
-    def error(cls, description: str):
+    def error(cls, description: str, obj: Optional[Reference]=None):
         """
-        Creates an ``Issue`` with ERROR severity
+        Creates an ``Issue`` with ERROR severity for related git object
         """
-        return cls(Level.ERROR, description)
+        return cls(Level.ERROR, description, obj)
 
-    def __init__(self, level: Level, description: str):
+    def __init__(self, level: Level, description: str, obj: Optional[Reference]=None):
         """
         :param level: Describes severity of the Issue
         :param description: Explanation of what is wrong
         """
         self.level = level
         self.description = description
+        self.obj = obj
+
+    def is_created_between(self, date_from: datetime, date_to: datetime) -> bool:
+        if self.obj:
+            obj_date = None
+
+            if hasattr(self.obj, 'committed_datetime'):
+                obj_date = self.obj.committed_datetime
+            elif hasattr(self.obj, 'commit'):
+                obj_date = self.obj.commit.committed_datetime
+            elif hasattr(self.obj.object, 'committed_datetime'):
+                obj_date = self.obj.object.committed_datetime
+            
+            return date_from < obj_date.replace(tzinfo=None) < date_to if obj_date else True
+        
+        return True
 
     def __repr__(self):
-        return "Issue(level={level}, description='{desc}')".format(level=self.level, desc=self.description)
+        return "Issue(level={level}, description='{desc}', obj='{obj}')".format(level=self.level, desc=self.description, obj=self.obj)
 
 
 class Section:
@@ -93,13 +111,16 @@ class Section:
     def change_severity(self, to: Level):
         for issue in self.issues:
             issue.level = to
+    
+    def consider_issues_in_period(self, date_from: datetime, date_to: datetime):
+        self.issues = [issue for issue in self.issues if issue.is_created_between(date_from, date_to)]
 
     def __repr__(self):
         return "Section(rule={rule}, title='{title}')".format(rule=self.rule, title=self.title)
 
 
 class Report:
-    def __init__(self, working_dir: str, stats: dict, sections: list):
+    def __init__(self, working_dir: str, stats: dict, sections: List[Section]):
         self.working_dir = working_dir
         self.stats = stats
         self.sections = sections if sections else []
@@ -111,3 +132,7 @@ class Report:
         errors = [section for section in self.sections if
                   section.contains_errors or (are_warnings_errors and section.contains_warns)]
         return len(errors) > 0
+
+    def consider_issues_only_in_period(self, date_from: datetime, date_to: datetime):
+        for section in self.sections:
+            section.consider_issues_in_period(date_from, date_to)
